← Back to team overview

gtg team mailing list archive

[Merge] lp:~nmaitre/gtg/conform-to-pep394 into lp:gtg

 

Nicolas Maître has proposed merging lp:~nmaitre/gtg/conform-to-pep394 into lp:gtg.

Requested reviews:
  Gtg developers (gtg)

For more details, see:
https://code.launchpad.net/~nmaitre/gtg/conform-to-pep394/+merge/88589

Modified the shebang lines to use the python2 executable, as recommended in PEP-394.
This might be incompatible with old distributions not shipping a python2 link/executable though...

I have also fixed a tiny bug where variables tname and vname are confused. Even if I've not been able to produce a misbehaviour with that bug, the confusion/error is pretty obvious.
-- 
https://code.launchpad.net/~nmaitre/gtg/conform-to-pep394/+merge/88589
Your team Gtg developers is requested to review the proposed merge of lp:~nmaitre/gtg/conform-to-pep394 into lp:gtg.
=== modified file 'AUTHORS'
--- AUTHORS	2012-01-14 07:06:41 +0000
+++ AUTHORS	2012-01-15 00:38:24 +0000
@@ -85,4 +85,4 @@
 * João Ascenso <joaoricardoascenso@xxxxxxxxx>
 * Jean-François Fortin Tam <nekohayo@xxxxxxxxx>
 * Richard Klein <kleinric@xxxxxxxxx>
-* Nicolas Maître <https://launchpad.net/~nmaitre> (no email provided)
+* Nicolas Maître <nimai@xxxxxxxxx>

=== modified file 'GTG/core/datastore.py'
--- GTG/gtg.py	2011-11-19 21:41:08 +0000
+++ GTG/gtg.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Gettings Things Gnome! - a personal organizer for the GNOME desktop

=== modified file 'GTG/gtk/crashhandler.py'
--- GTG/gtk/crashhandler.py	2011-08-26 14:47:53 +0000
+++ GTG/gtk/crashhandler.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # Copyright 2010 David D. Lowe
 # All rights reserved.
 #

=== modified file 'GTG/tools/networkmanager.py'
--- GTG/tools/networkmanager.py	2010-08-06 21:58:34 +0000
+++ GTG/tools/networkmanager.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/bin/env python
+#!/usr/bin/env python2
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'gtcli'
--- gtcli	2011-11-28 22:18:33 +0000
+++ gtcli	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding:utf-8 -*-
 
 '''Command line user interface for manipulating tasks in gtg.

=== modified file 'gtg'
--- gtg	2010-09-08 09:50:32 +0000
+++ gtg	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding:utf-8 -*-
 
 # -----------------------------------------------------------------------------

=== modified file 'gtg_new_task'
--- gtg_new_task	2011-11-19 21:41:08 +0000
+++ gtg_new_task	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding:utf-8 -*-
 
 # -----------------------------------------------------------------------------

=== modified file 'profile.py'
--- profile.py	2011-11-19 21:41:08 +0000
+++ profile.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 import GTG.gtg
 import cProfile
 import pstats

=== modified file 'run-tests'
--- run-tests	2010-09-08 09:50:32 +0000
+++ run-tests	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Gettings Things Gnome! - a personal organizer for the GNOME desktop

=== modified file 'scripts/anonymize_task_file.py'
--- scripts/anonymize_task_file.py	2010-08-03 08:04:26 +0000
+++ scripts/anonymize_task_file.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 ### -*- coding: utf-8 -*-
 # Copyright © 2010 Marko Kevac <marko@xxxxxxxxx>
 #

=== modified file 'scripts/gtg_stress_test'
--- scripts/gtg_stress_test	2011-08-12 14:23:16 +0000
+++ scripts/gtg_stress_test	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding:utf-8 -*-
 
 # -----------------------------------------------------------------------------

=== modified file 'scripts/pep8.py'
--- scripts/pep8.py	2009-12-03 09:47:09 +0000
+++ scripts/pep8.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # pep8.py - Check Python source code formatting, according to PEP 8
 # Copyright (C) 2006 Johann C. Rocholl <johann@xxxxxxxxxxxxxxxx>
 #

=== modified file 'scripts/profile_interpret.sh'
--- scripts/profile_interpret.sh	2010-06-22 20:19:47 +0000
+++ scripts/profile_interpret.sh	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 import pstats
 p = pstats.Stats('gtg.prof')
 p.strip_dirs().sort_stats("cumulative").print_stats(20)

=== modified file 'setup.py'
--- setup.py	2011-11-28 21:23:46 +0000
+++ setup.py	2012-01-15 00:38:24 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Gettings Things Gnome! - a personal organizer for the GNOME desktop
--- GTG/core/datastore.py	2011-12-23 07:50:36 +0000
+++ GTG/core/datastore.py	2012-01-15 00:38:24 +0000
@@ -30,7 +30,6 @@
 """
 
 import threading
-import gobject
 import uuid
 import os.path
 from collections import deque
@@ -160,7 +159,7 @@
                 self.added_tag.pop(vname)
                 Log.debug("********* view added %s *******" % vname)
             else:
-                print "Warning: Trying to add tag %s multiple times" %tname
+                print "Warning: Trying to add view %s multiple times" %vname
         #we create a new view from a name
         vname = viewname.encode("UTF-8")
         #if vname not in self.tags:
@@ -175,8 +174,8 @@
                 #puts for save on exit
                 self.add_view_control(vname, params)
             else:
-                #it means that we are in the process of adding the tag
-                tag = self.added_tag[tname]
+                #it means that we are in the process of adding the view
+                tag = self.added_tag[vname]
         else:
             raise IndexError('view %s was already in the datastore' %vname)
         return tag

=== modified file 'GTG/gtg.py'